GCPluginInfo

Struct GCPluginInfo 

#[repr(transparent)]
pub struct GCPluginInfo(sGCPluginInfo);
A struct that represents the information of a plugin. This struct is meant to be initialized by the plugin and send to the gateway. It also the owner of the data it represents.

Tuple Fields

0: sGCPluginInfo

Implementations



impl GCPluginInfo

pub fn new( name: &str, version: &str, plugin_ifc_version: &str, features: u64, ) -> Self

Create a new plugin info object

This creates 3 additional allocations

pub fn new_from_c( name: CString, version: CString, plugin_ifc_version: CString, features: u64, ) -> Self

Create a new plugin info object from C strings

pub fn name(&self) -> String

Get the name of the plugin as a Rust string

This method allocates a new string

pub fn version(&self) -> String

Get the version of the plugin as a Rust string

This method allocates a new string

pub fn plugin_ifc_version(&self) -> String

Get the plugin interface version of the plugin as a Rust string

This method allocates a new string

pub fn c_name(&self) -> &CStr

Get the name of the plugin as a C string

pub fn c_version(&self) -> &CStr

Get the version of the plugin as a C string

pub fn c_plugin_ifc_version(&self) -> &CStr

Get the plugin interface version of the plugin as a C string

pub fn features(&self) -> u64

Get the features of the plugin as a C string